@@ -2114,8 +2114,8 @@ void Connection::sendGetGroups(QString id, QString type)
 {
     AttributeList attrs;
 
-    ProtocolTreeNode listNode("list");
-    attrs.insert("type",type);
+    ProtocolTreeNode listNode(type);
+    attrs.insert("type","list");
     listNode.setAttributes(attrs);
 
     ProtocolTreeNode iqNode("iq");
@@ -2124,7 +2124,7 @@ void Connection::sendGetGroups(QString id, QString type)
     attrs.insert("id",id);
     attrs.insert("type","get");
     attrs.insert("to","g.us");
-    attrs.insert("xmlns","w:g");
+    attrs.insert("xmlns","w:g2");
     iqNode.setAttributes(attrs);
     iqNode.addChild(listNode);
 
@@ -2394,7 +2394,6 @@ void Connection::sendClientConfig(QString platform)
     AttributeList attrs;
 
     ProtocolTreeNode configNode("config");
-    attrs.insert("xmlns","urn:xmpp:whatsapp:push");
     attrs.insert("platform", platform);
     attrs.insert("lg", language.isEmpty() ? "zz" : language);
     attrs.insert("lc", country.isEmpty() ?  "ZZ" : country);
@@ -2404,6 +2403,7 @@ void Connection::sendClientConfig(QString platform)
     attrs.clear();
     attrs.insert("id",id);
     attrs.insert("type","set");
+    attrs.insert("xmlns","urn:xmpp:whatsapp:push");
     attrs.insert("to",domain);
     iqNode.setAttributes(attrs);
     iqNode.addChild(configNode);
